"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const Koa = require("koa");
const bodyparser = require("koa-bodyparser");
const openapi_backend_1 = require("openapi-backend");
class Mock extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Mock);
        await this.startMockServer(args.file, flags.port);
    }
    async startMockServer(definition, port = 9000) {
        const api = new openapi_backend_1.default({ definition });
        api.register({
            validationFail: (c, ctx) => {
                ctx.status = 400;
                ctx.body = { err: c.validation.errors };
            },
            notFound: (c, ctx) => {
                ctx.status = 404;
                ctx.body = { err: 'not found' };
            },
            notImplemented: (c, ctx) => {
                const { status, mock } = c.api.mockResponseForOperation(c.operation.operationId);
                ctx.status = status;
                ctx.body = mock;
            },
        });
        await api.init();
        const app = new Koa();
        app.use(bodyparser());
        app.use((ctx) => api.handleRequest({
            method: ctx.request.method,
            path: ctx.request.path,
            body: ctx.request.body,
            query: ctx.request.query,
            headers: ctx.request.headers,
        }, ctx));
        const server = app.listen(port);
        process.on('disconnect', () => server.close());
        this.log(`Mock server running at http://localhost:${port}`);
    }
}
Mock.description = 'describe the command here';
Mock.examples = [`$ openapi mock ./openapi.yml`];
Mock.flags = {
    help: command_1.flags.help({ char: 'h' }),
    port: command_1.flags.integer({ char: 'p', description: 'port', default: 9000 }),
};
Mock.args = [{ name: 'file', required: true }];
exports.default = Mock;
